==> haskell-bytestring-strict-builder-0.4.5-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-bytestring-strict-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bytestring-strict-builder
version: 0.4.5
id: bytestring-strict-builder-0.4.5-I0Ehywg0AoS9bYVGMdsGC5
key: bytestring-strict-builder-0.4.5-I0Ehywg0AoS9bYVGMdsGC5
license: MIT
copyright: (c) 2017, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/bytestring-strict-builder
synopsis: An efficient strict bytestring builder
description:
    According to
    <https://github.com/nikita-volkov/bytestring-builders-benchmark the competition benchmarks>,
    this library provides on average the fastest builder of strict bytestrings.
    .
    Practical benchmarks have proven it to be highly performant as well.
    The encoders from the \"postgresql-binary\" library have shown
    a stable performance improvement by factors of up to 10 after the migration
    from the standard builder to \"bytestring-strict-builder\".
category: Text, ByteString, Builders, Serialization
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
exposed-modules:
    ByteString.StrictBuilder
hidden-modules: ByteString.StrictBuilder.Prelude
                ByteString.StrictBuilder.Population
                ByteString.StrictBuilder.Population.UncheckedShifting
                ByteString.StrictBuilder.UTF8
abi: 1f4a4e236d262f56640d1f8ed302b23a
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/bytestring-strict-builder-0.4.5
library-dirs: /usr/lib/ghc-8.0.2/site-local/bytestring-strict-builder-0.4.5
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/bytestring-strict-builder-0.4.5
hs-libraries: HSbytestring-strict-builder-0.4.5-I0Ehywg0AoS9bYVGMdsGC5
depends:
    base-4.9.1.0 base-prelude-1.2.0.1-HJh3WMXaeu8jTCoycvBYB
    bytestring-0.10.8.1 semigroups-0.18.3-5xL9BgkWQsCGwo6YahyMCM
haddock-interfaces: /usr/share/doc/haskell-bytestring-strict-builder/html/bytestring-strict-builder.haddock
haddock-html: /usr/share/doc/haskell-bytestring-strict-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bytestring-strict-builder-0.4.5-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-bytestring-strict-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bytestring-strict-builder
version: 0.4.5
id: bytestring-strict-builder-0.4.5-5MXDX8KK6On2ooOaqK4WY5
key: bytestring-strict-builder-0.4.5-5MXDX8KK6On2ooOaqK4WY5
license: MIT
copyright: (c) 2017, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/bytestring-strict-builder
synopsis: An efficient strict bytestring builder
description:
    According to
    <https://github.com/nikita-volkov/bytestring-builders-benchmark the competition benchmarks>,
    this library provides on average the fastest builder of strict bytestrings.
    .
    Practical benchmarks have proven it to be highly performant as well.
    The encoders from the \"postgresql-binary\" library have shown
    a stable performance improvement by factors of up to 10 after the migration
    from the standard builder to \"bytestring-strict-builder\".
category: Text, ByteString, Builders, Serialization
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
indefinite: False
exposed-modules:
    ByteString.StrictBuilder
hidden-modules: ByteString.StrictBuilder.Prelude
                ByteString.StrictBuilder.Population
                ByteString.StrictBuilder.Population.UncheckedShifting
                ByteString.StrictBuilder.UTF8
abi: 271b4423b9b417c7c13243b94e5d3b3c
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/bytestring-strict-builder-0.4.5
library-dirs: /usr/lib/ghc-8.2.1/site-local/bytestring-strict-builder-0.4.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/bytestring-strict-builder-0.4.5
hs-libraries: HSbytestring-strict-builder-0.4.5-5MXDX8KK6On2ooOaqK4WY5
depends:
    semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP bytestring-0.10.8.2
    base-prelude-1.2.0.1-GfnST6wywTP6rNqw8BISGT base-4.10.0.0
abi-depends: semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP=aad58cc65045b8e62f1806217258d930
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             base-prelude-1.2.0.1-GfnST6wywTP6rNqw8BISGT=be7241d647b311157e69b90e57b06d24
             base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
haddock-interfaces: /usr/share/doc/haskell-bytestring-strict-builder/html/bytestring-strict-builder.haddock
haddock-html: /usr/share/doc/haskell-bytestring-strict-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
